package com.fs.fastGpt.service;

import java.util.List;
import com.fs.fastGpt.domain.FastgptTag;

/**
 * ai标签Service接口
 * 
 * @author fs
 * @date 2024-12-20
 */
public interface IFastgptTagService 
{
    /**
     * 查询ai标签
     * 
     * @param id ai标签主键
     * @return ai标签
     */
    public FastgptTag selectFastgptTagById(Long id);

    /**
     * 查询ai标签列表
     * 
     * @param fastgptTag ai标签
     * @return ai标签集合
     */
    public List<FastgptTag> selectFastgptTagList(FastgptTag fastgptTag);

    /**
     * 新增ai标签
     * 
     * @param fastgptTag ai标签
     * @return 结果
     */
    public int insertFastgptTag(FastgptTag fastgptTag);

    /**
     * 修改ai标签
     * 
     * @param fastgptTag ai标签
     * @return 结果
     */
    public int updateFastgptTag(FastgptTag fastgptTag);

    /**
     * 批量删除ai标签
     * 
     * @param ids 需要删除的ai标签主键集合
     * @return 结果
     */
    public int deleteFastgptTagByIds(Long[] ids);

    /**
     * 删除ai标签信息
     * 
     * @param id ai标签主键
     * @return 结果
     */
    public int deleteFastgptTagById(Long id);
}
